/**************************************************************************************

  Interfacing PIC16F887 microcontroller with DS1307 RTC.
  Time and date are displayed on 16x2 LCD.
  C Code for mikroC PRO for PIC compiler.
  Internal oscillator used @ 8MHz
  Configuration words: CONFIG1 = 0x2CD4
                       CONFIG2 = 0x0700
  This is a free software with NO WARRANTY.
  https://simple-circuit.com/

***************************************************************************************/

// LCD module connections
sbit LCD_RS at RD0_bit;
sbit LCD_EN at RD1_bit;
sbit LCD_D4 at RD2_bit;
sbit LCD_D5 at RD3_bit;
sbit LCD_D6 at RD4_bit;
sbit LCD_D7 at RD5_bit;
sbit LCD_RS_Direction at TRISD0_bit;
sbit LCD_EN_Direction at TRISD1_bit;
sbit LCD_D4_Direction at TRISD2_bit;
sbit LCD_D5_Direction at TRISD3_bit;
sbit LCD_D6_Direction at TRISD4_bit;
sbit LCD_D7_Direction at TRISD5_bit;
// end LCD module connections

#include <DS1307.c>  // include DS1307 RTC driver source file

// DS1307 library variable declaration
RTC_Time *mytime;

void rtc_print()
{
  char txt[17];
  // print time
  sprinti(txt, "TIME: %02u:%02u:%02u", (int)mytime->hours, (int)mytime->minutes, (int)mytime->seconds);
  LCD_Out(1, 1, txt);
  // print date
  sprinti(txt, "DATE: %02u-%02u-20%02u", (int)mytime->day, (int)mytime->month, (int)mytime->year);
  LCD_Out(2, 1, txt);
}

// main function
void main()
{
  OSCCON = 0x70;            // set internal oscillator to 8MHz
  delay_ms(1000);           // wait a second
  
  I2C1_Init(100000);        // initialize I2C communication
  Lcd_Init();               // initialize LCD module
  Lcd_Cmd(_LCD_CURSOR_OFF); // cursor off
  Lcd_Cmd(_LCD_CLEAR);      // clear LCD

  // read current time and date from the RTC chip
  mytime = RTC_Get();
  // print them
  rtc_print();

  // set RTC time to 15:43:12 (hh:mm:ss) and date to 25-12-18 (dd-mm-yy)
  mytime->hours   = 15;
  mytime->minutes = 43;
  mytime->seconds = 12;
  mytime->day   = 25;
  mytime->month = 12;
  mytime->year  = 18;
  // write time and date to the RTC chip
  RTC_Set(mytime);

  // enable RTC oscillator
  OSC_Enable();

  // enable SQWE output with frequency of 1Hz
  SQWE_Set(OUT_1Hz);

  while(1)
  {
    // read current time and date from the RTC chip
    mytime = RTC_Get();
    // print them
    rtc_print();

    delay_ms(200);  // wait 100 ms

  }

}
// end of code.